@@ -111,57 +111,57 @@ ffts <- function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70,
       assign(names(opt.argms)[q], opt.argms[[q]])
   
   #check path to working directory
-  if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
+  if (is.null(path)) path <- getwd() else {if (!dir.exists(path)) stop("'path' provided does not exist") else
     setwd(path)
   }  
   
     #if X is not a data frame
-    if(!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
+    if (!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
     
-  if(!all(c("sound.files", "selec", 
+  if (!all(c("sound.files", "selec", 
             "start", "end") %in% colnames(X))) 
     stop(paste(paste(c("sound.files", "selec", "start", "end")[!(c("sound.files", "selec", 
                                                                    "start", "end") %in% colnames(X))], collapse=", "), "column(s) not found in data frame"))
   
   #if there are NAs in start or end stop
-  if(any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")  
+  if (any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")  
   
   #if end or start are not numeric stop
-  if(all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
+  if (all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
   
   #if any start higher than end stop
-  if(any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))  
+  if (any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))  
   
   #if any selections longer than 20 secs stop
-  if(any(X$end - X$start>20)) stop(paste(length(which(X$end - X$start>20)), "selection(s) longer than 20 sec"))  
+  if (any(X$end - X$start>20)) stop(paste(length(which(X$end - X$start>20)), "selection(s) longer than 20 sec"))  
   options( show.error.messages = TRUE)
   
   #if bp is not vector or length!=2 stop
-  if(!is.null(bp)) {if(!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
-    if(!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")}}
+  if (!is.null(bp)) {if (!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
+    if (!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")}}
   
   #if ff.method argument  
-  if(!any(ff.method == "seewave", ff.method == "tuneR")) stop(paste("ff.method", ff.method, "is not recognized"))  
+  if (!any(ff.method == "seewave", ff.method == "tuneR")) stop(paste("ff.method", ff.method, "is not recognized"))  
   
   #return warning if not all sound files were found
   if (!is_extended_selection_table(X))
   {recs.wd <- list.files(path = getwd(), pattern = "\\.wav$", ignore.case = TRUE)
-  if(length(unique(X$sound.files[(X$sound.files %in% recs.wd)])) != length(unique(X$sound.files)) & pb) 
+  if (length(unique(X$sound.files[(X$sound.files %in% recs.wd)])) != length(unique(X$sound.files)) & pb) 
     cat(paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% recs.wd)])), 
                   ".wav file(s) not found"))
   
   #count number of sound files in working directory and if 0 stop
   d <- which(X$sound.files %in% recs.wd) 
-  if(length(d) == 0){
+  if (length(d) == 0){
     stop("The .wav files are not in the working directory")
   }  else X <- X[d, , drop = FALSE]
   }
   
   #if parallel is not numeric
-  if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
-  if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
+  if (!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
+  if (any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
-  if(pb) {if(img) cat("Creating spectrograms overlaid with fundamental frequency measurements:") else
+  if (pb) {if (img) cat("Creating spectrograms overlaid with fundamental frequency measurements:") else
     cat("Measuring fundamental frequency:")}
   
   fftsFUN <- function(X, i, bp, wl, threshold){
@@ -171,16 +171,16 @@ ffts <- function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70,
     f <- r$sample.rate
     
     b<- bp 
-    if(!is.null(b)) {if(b[2] > ceiling(f/2000) - 1) b[2] <- ceiling(f/2000) - 1 
+    if (!is.null(b)) {if (b[2] > ceiling(f/2000) - 1) b[2] <- ceiling(f/2000) - 1 
     b <- b * 1000}
     
     r <- read_wave(X = X, index = i)
     
     # calculate fundamental frequency at each time point     
-    if(ff.method == "seewave")
+    if (ff.method == "seewave")
       ffreq1 <- seewave::fund(r, fmax= b[2], f = f, ovlp = ovlp, threshold = threshold, plot = FALSE) else
       {
-        if(any(slotNames(r) == "stereo")) if(r@stereo) r <- mono(r, which = "both")
+        if (any(slotNames(r) == "stereo")) if (r@stereo) r <- mono(r, which = "both")
         suppressWarnings(ff1 <- tuneR::FF(tuneR::periodogram(r, width = wl, overlap = wl*ovlp / 100), peakheight = (100 - threshold) / 100)/1000)
         ff2 <- seq(0, X$end[i] - X$start[i], length.out = length(ff1))
         
@@ -190,13 +190,13 @@ ffts <- function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70,
     ffreq <- matrix(ffreq1[!is.na(ffreq1[,2]),], ncol = 2)  
     ffreq <- matrix(ffreq[ffreq[,2] > b[1]/1000,], ncol = 2)
 
-    if(nrow(ffreq) < 2) {
+    if (nrow(ffreq) < 2) {
       apfund <- list()
       apfund$x <- ffreq1[, 1]
       apfund$y <- rep(NA, length.out)
       apfund1 <- apfund
     } else {
-      if(!clip.edges)  {
+      if (!clip.edges)  {
         apfund <- approx(ffreq[,1], ffreq[,2], xout = seq(from = ffreq1[1, 1],
                                                           to = ffreq1[nrow(ffreq1), 1], length.out = length.out), 
                          method = "linear") 
@@ -210,11 +210,11 @@ ffts <- function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70,
         #calculate time at start and end with no amplitude detected (duration of clipped edges)
         durend1 <- suppressWarnings(diff(range(ffreq1[,1][rev(cumsum(rev(ffreq1[,2])) == 0)])))
         durend <- durend1
-        if(is.infinite(durend) | is.na(durend)) durend <- 0
+        if (is.infinite(durend) | is.na(durend)) durend <- 0
         
         durst1 <- suppressWarnings(diff(range(ffreq1[,1][cumsum(ffreq1[,2]) == 0])))   
         durst <- durst1
-        if(is.infinite(durst) | is.na(durst)) durst <- 0
+        if (is.infinite(durst) | is.na(durst)) durst <- 0
         
         by.dur <- mean(diff(apfund$x))
         clipst <- length(seq(from = 0, to = durst, by = by.dur))
@@ -223,12 +223,12 @@ ffts <- function(X, wl = 512, length.out = 20, wn = "hanning", ovlp = 70,
         apfund1 <- apfund
         apfund1$y <- c(rep(NA, clipst) ,apfund$y, rep(NA, clipend))
         
-        if(is.infinite(durst1) | is.na(durst1)) apfund1$y <- apfund1$y[-1]
-        if(is.infinite(durend1) | is.na(durend1)) apfund1$y <- apfund1$y[-length(apfund1$y)]
+        if (is.infinite(durst1) | is.na(durst1)) apfund1$y <- apfund1$y[-1]
+        if (is.infinite(durend1) | is.na(durend1)) apfund1$y <- apfund1$y[-length(apfund1$y)]
       }
     }
     
-    if(img) 
+    if (img) 
       trackfreqs(X[i, , drop = FALSE], wl = wl, osci = FALSE, leglab = leglab, pb = FALSE, wn = wn,
                  parallel = 1, path = path, img.suffix =  img.suffix, ovlp = ovlp,
                  custom.contour = data.frame(sound.files = X$sound.files[i], selec = X$selec[i], t(apfund$y)), ...)
