@@ -118,88 +118,88 @@ lspec <- function(X = NULL, flim = c(0, 22), sxrow = 5, rows = 10, collevels = s
       assign(names(opt.argms)[q], opt.argms[[q]])
   
   #check path to working directory
-  if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
+  if (is.null(path)) path <- getwd() else {if (!dir.exists(path)) stop("'path' provided does not exist") else
     setwd(path)
   }  
   
   #if sel.comment column not found create it
-  if(is.null(X$sel.comment) & !is.null(X)) X<-data.frame(X,sel.comment="")
+  if (is.null(X$sel.comment) & !is.null(X)) X<-data.frame(X,sel.comment="")
   
   #read files
   files <- list.files(pattern = "\\.wav$", ignore.case = TRUE)  
   
   #stop if files are not in working directory
-  if(length(files) == 0) stop("no .wav files in working directory")
+  if (length(files) == 0) stop("no .wav files in working directory")
   
   #subet based on file list provided (flist)
   if (!is.null(flist)) files <- files[files %in% flist]
   if (length(files) == 0)  stop("selected .wav files are not in working directory")
   
   #check that all files are in working directory
-  if(!is.null(X)) {manloc <- X
+  if (!is.null(X)) {manloc <- X
   files<-files[files %in% X$sound.files]
   }  else manloc <- NULL
   
-  if(!is.null(X)) {
+  if (!is.null(X)) {
   
     #if X is not a data frame
-    if(!any(is.data.frame(X), is_selection_table(X))) stop("X is not of a class 'data.frame' or 'selection_table'")
+    if (!any(is.data.frame(X), is_selection_table(X))) stop("X is not of a class 'data.frame' or 'selection_table'")
     
   #stop if files are not in working directory
-  if(length(files) == 0) stop(".wav files in X are not in working directory")
+  if (length(files) == 0) stop(".wav files in X are not in working directory")
   
   #if there are NAs in start or end stop
-  if(any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end columns")  
+  if (any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end columns")  
   
   #check if all columns are found
-  if(any(!(c("sound.files", "selec", "start", "end") %in% colnames(X)))) 
+  if (any(!(c("sound.files", "selec", "start", "end") %in% colnames(X)))) 
     stop(paste(paste(c("sound.files", "selec", "start", "end")[!(c("sound.files", "selec", 
                                                                    "start", "end") %in% colnames(X))], collapse=", "), "column(s) not found in data frame"))
 
   #if end or start are not numeric stop
-  if(all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
+  if (all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
   
   #if any start higher than end stop
-  if(any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))  
+  if (any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))  
   }
  
 #if flim is not vector or length!=2 stop
-  if(is.null(flim)) stop("'flim' must be a numeric vector of length 2") else {
-    if(!is.vector(flim)) stop("'flim' must be a numeric vector of length 2") else{
-      if(!length(flim) == 2) stop("'flim' must be a numeric vector of length 2")}}   
+  if (is.null(flim)) stop("'flim' must be a numeric vector of length 2") else {
+    if (!is.vector(flim)) stop("'flim' must be a numeric vector of length 2") else{
+      if (!length(flim) == 2) stop("'flim' must be a numeric vector of length 2")}}   
   
   #if wl is not vector or length!=1 stop
-  if(is.null(wl)) stop("'wl' must be a numeric vector of length 1") else {
-    if(!is.vector(wl)) stop("'wl' must be a numeric vector of length 1") else{
-      if(!length(wl) == 1) stop("'wl' must be a numeric vector of length 1")}}  
+  if (is.null(wl)) stop("'wl' must be a numeric vector of length 1") else {
+    if (!is.vector(wl)) stop("'wl' must be a numeric vector of length 1") else{
+      if (!length(wl) == 1) stop("'wl' must be a numeric vector of length 1")}}  
   
   #if sxrow is not vector or length!=1 stop
-  if(is.null(sxrow)) stop("'sxrow' must be a numeric vector of length 1") else {
-    if(!is.vector(sxrow)) stop("'sxrow' must be a numeric vector of length 1") else{
-      if(!length(sxrow) == 1) stop("'sxrow' must be a numeric vector of length 1")}}  
+  if (is.null(sxrow)) stop("'sxrow' must be a numeric vector of length 1") else {
+    if (!is.vector(sxrow)) stop("'sxrow' must be a numeric vector of length 1") else{
+      if (!length(sxrow) == 1) stop("'sxrow' must be a numeric vector of length 1")}}  
   
   #if rows is not vector or length!=1 stop
-  if(is.null(rows)) stop("'rows' must be a numeric vector of length 1") else {
-    if(!is.vector(rows)) stop("'rows' must be a numeric vector of length 1") else{
-      if(!length(rows) == 1) stop("'rows' must be a numeric vector of length 1")}}  
+  if (is.null(rows)) stop("'rows' must be a numeric vector of length 1") else {
+    if (!is.vector(rows)) stop("'rows' must be a numeric vector of length 1") else{
+      if (!length(rows) == 1) stop("'rows' must be a numeric vector of length 1")}}  
   
   #if picsize is not vector or length!=1 stop
-  if(is.null(cex)) stop("'picsize' must be a numeric vector of length 1") else {
-    if(!is.vector(cex)) stop("'picsize' must be a numeric vector of length 1") else{
-      if(!length(cex) == 1) stop("'picsize' must be a numeric vector of length 1")}}  
+  if (is.null(cex)) stop("'picsize' must be a numeric vector of length 1") else {
+    if (!is.vector(cex)) stop("'picsize' must be a numeric vector of length 1") else{
+      if (!length(cex) == 1) stop("'picsize' must be a numeric vector of length 1")}}  
   
   #if it argument is not "jpeg" or "tiff" 
-  if(!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))  
+  if (!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))  
   
   #wrap img creating function
-  if(it == "jpeg") imgfun <- jpeg else imgfun <- tiff
+  if (it == "jpeg") imgfun <- jpeg else imgfun <- tiff
   
   #if parallel is not numeric
-  if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
-  if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
+  if (!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
+  if (any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
   # redo
-  if(!redo) 
+  if (!redo) 
     files <- files[!gsub(".wav$","", list.files(pattern = "\\.wav$", ignore.case = TRUE),ignore.case = TRUE) %in% 
       unlist(sapply(strsplit(as.character(list.files(pattern = paste(it, "$", 
                                                                      sep = ""), ignore.case = TRUE)), "-p",fixed = TRUE), "[",1))]
@@ -207,7 +207,7 @@ lspec <- function(X = NULL, flim = c(0, 22), sxrow = 5, rows = 10, collevels = s
   files <- files[!is.na(files)]
   
   #stop if files are not in working directory
-  if(length(files) == 0) stop("all .wav files have been processed")
+  if (length(files) == 0) stop("all .wav files have been processed")
   
   #create function for making spectrograms
   lspecFUN <-function(z, fl, sl, li, ml, malo) {
@@ -216,14 +216,14 @@ lspec <- function(X = NULL, flim = c(0, 22), sxrow = 5, rows = 10, collevels = s
     rec <- tuneR::readWave(z) #read wave file 
     f <- rec@samp.rate #set sampling rate
     frli<- fl #in case flim is higher than can be due to sampling rate
-    if(frli[2] > ceiling(f/2000) - 1) frli[2] <- ceiling(f/2000) - 1 
+    if (frli[2] > ceiling(f/2000) - 1) frli[2] <- ceiling(f/2000) - 1 
     dur <- seewave::duration(rec) #set duration    
     
-    if(!length(grep("[^[:digit:]]", as.character(dur/sl))))  #if duration is multiple of sl
+    if (!length(grep("[^[:digit:]]", as.character(dur/sl))))  #if duration is multiple of sl
       rec <- seewave::cutw(wave = rec, f = f, from = 0, to = dur-0.001, output = "Wave") #cut a 0.001 segment of rec     
     dur <- seewave::duration(rec) #set duration    
     
-    if(!is.null(malo)) ml <- ml[ml$sound.files == z,] #subset X data
+    if (!is.null(malo)) ml <- ml[ml$sound.files == z,] #subset X data
     
     #loop over pages 
     no.out <-lapply(1:ceiling(dur/(li*sl)), function(j)  
@@ -237,25 +237,25 @@ lspec <- function(X = NULL, flim = c(0, 22), sxrow = 5, rows = 10, collevels = s
       x <- 0
       while(x <= li-1){
         x <- x + 1
-        if(all(((x)*sl+li*(sl)*(j-1))-sl<dur & (x)*sl+li*(sl)*(j-1)<dur)){  #for rows with complete spectro
+        if (all(((x)*sl+li*(sl)*(j-1))-sl<dur & (x)*sl+li*(sl)*(j-1)<dur)){  #for rows with complete spectro
           spectro_wrblr_int(rec, f = f, wl = wl, flim = frli, tlim = c(((x)*sl+li*(sl)*(j-1))-sl, (x)*sl+li*(sl)*(j-1)), 
                   ovlp = ovlp, collevels = collevels, grid = gr, scale = FALSE, palette = pal, axisX = TRUE, fast.spec = fast.spec)
-          if(x == 1) text((sl-0.01*sl) + (li*sl)*(j - 1), frli[2] - (frli[2]-frli[1])/10, paste(substring(z, first = 1, 
+          if (x == 1) text((sl-0.01*sl) + (li*sl)*(j - 1), frli[2] - (frli[2]-frli[1])/10, paste(substring(z, first = 1, 
                                                                                                           last = nchar(z)-4), "-p", j, sep = ""), pos = 2, font = 2, cex = cex)
-          if(!is.null(malo))  {if(any(!is.na(ml$sel.comment))) {
+          if (!is.null(malo))  {if (any(!is.na(ml$sel.comment))) {
             l <- paste(ml$selec, "-'", ml$sel.comment, "'", sep="") 
            l[is.na(ml$sel.comment)] <- ml$selec[is.na(ml$sel.comment)]} else l <- ml$selec
                                mapply(function(s, e, labels, fli = frli){
                                  abline(v = c(s, e), col = "red", lty = 2)
                                  text((s + e)/2,  fli[2] - 2*((fli[2] - fli[1])/12), labels = labels, font = 4)},
                                  s = ml$start, e = ml$end,labels = l)} } else {
-                                   if(all(((x)*sl+li*(sl)*(j-1))-sl < dur & (x)*sl+li*(sl)*(j-1)>dur)){ #for rows with incomplete spectro (final row)
+                                   if (all(((x)*sl+li*(sl)*(j-1))-sl < dur & (x)*sl+li*(sl)*(j-1)>dur)){ #for rows with incomplete spectro (final row)
                                      spectro_wrblr_int(seewave::pastew(seewave::noisew(f = f,  d = (x)*sl+li*(sl)*(j-1)-dur+1,  type = "unif",   
                                                            listen = FALSE,  output = "Wave"), seewave::cutw(wave = rec, f = f, from = ((x)*sl+li*(sl)*(j-1))-sl,
                                                                                                    to = dur, output = "Wave"), f =f,  output = "Wave"), f = f, wl = wl, flim = frli, 
                                              tlim = c(0, sl), ovlp = ovlp, collevels = collevels, grid = gr, scale = FALSE, palette = pal, axisX = FALSE, fast.spec = fast.spec)
                                      
-        if(x == 1) text((sl-0.01*sl) + (li*sl)*(j - 1), frli[2] - (frli[2]-frli[1])/10, paste(substring(z, first = 1, 
+        if (x == 1) text((sl-0.01*sl) + (li*sl)*(j - 1), frli[2] - (frli[2]-frli[1])/10, paste(substring(z, first = 1, 
       last = nchar(z)-4), "-p", j, sep = ""), pos = 2, font = 2, cex = cex)                             
                                      
                                      #add white polygon add final row on part without signal
@@ -264,7 +264,7 @@ lspec <- function(X = NULL, flim = c(0, 22), sxrow = 5, rows = 10, collevels = s
                                      
                                      #add X lines and labels
                                      
-                                     if(!is.null(malo)) { if(any(!is.na(ml$sel.comment))) {
+                                     if (!is.null(malo)) { if (any(!is.na(ml$sel.comment))) {
                                        l <- paste(ml$selec,"-'",ml$sel.comment,"'",sep="")
                                        l[is.na(ml$sel.comment)] <- ml$selec[is.na(ml$sel.comment)]} else l <- ml$selec
                                                           lise <- ((x)*sl+li*(sl)*(j-1))-sl
