@@ -14,7 +14,7 @@
 #' the manipulation of sound files and other files produced by many of the \code{\link{warbleR}} function.
 #' @examples
 #' {
-#' open_wd()
+#' \donttest{open_wd()}
 #' }
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 #last modification on apr-16-2018 (MAS)
@@ -22,7 +22,7 @@
 open_wd <- function(path = getwd(), verbose = TRUE){
   
   #check path to working directory
-  if(!file.exists(path)) stop("'path' provided does not exist") 
+  if (!dir.exists(path)) stop("'path' provided does not exist") 
   
     if (.Platform['OS.type'] == "windows"){
     shell.exec(path)
