@@ -59,15 +59,18 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
       assign(names(opt.argms)[q], opt.argms[[q]])
   
   #stop if X is not a data frame
-  if(!is.data.frame(X))  stop("X is not a data frame")
+  if (!is.data.frame(X))  stop("X is not a data frame")
 
   #if it argument is not "jpeg" or "tiff" 
-  if(!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed")) 
+  if (!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed")) 
   # Initialize species names (common name)
   spn <- length(unique(X$English_name))
     
+  # reset graphic device
+  try(dev.off(), silent = TRUE)
+  
   # Set threshold for maximum number of panels per plot device
-  if(spn <= 16) mat <- par(mfrow = c(ceiling(sqrt(spn)), round(sqrt(spn),0))) else par(mfrow = c(4, 4)) 
+  if (spn <= 16) mat <- par(mfrow = c(ceiling(sqrt(spn)), round(sqrt(spn),0))) else par(mfrow = c(4, 4)) 
   par(mar = rep(0, 4))
   
   # Create a map per species, with the recordings plotted over each map
@@ -79,12 +82,12 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
     lat <- lat[!is.na(lat)]
     lon <- lon[!is.na(lon)]
     
-    if(all(length(lat) > 0, length(lon) > 0))
+    if (all(length(lat) > 0, length(lon) > 0))
     {if (abs(max(lon) - min(lon)) < 38) buf <- 12 else buf <- 5
      
-     if(img){
+     if (img){
        prop <- abs((min(lon) - buf)-(max(lon) + buf))/abs((min(lat) - buf)-(max(lat) + buf)) * 1.15
-       if(it == "tiff") tiff(filename = paste("Map of ", i, " recordings", ".tiff", sep = ""), 
+       if (it == "tiff") tiff(filename = paste("Map of ", i, " recordings", ".tiff", sep = ""), 
                              width = 480 * prop) else
          jpeg(filename = paste("Map of ", i, " recordings", ".jpeg", sep = ""), width = 480 * prop)
 
@@ -122,10 +125,10 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
                  ylim = c(min(lat) - buf, max(lat) + buf), fill = FALSE, add = TRUE)  
        
        # add points
-       points(lon, lat, pch = 21, cex = 1.8, col = "black", bg= heat.colors(10)[2])
+       points(lon, lat, pch = 21, cex = 1.8, col = "#E37222", bg= "#E37222")
        
        #add labels 
-       if(labels)
+       if (labels)
         text(lon, lat, labels = X$Recording_ID, cex = 0.7, pos = 4)
       
       # add scale
@@ -134,8 +137,8 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
      
        } else {
          #change margins
-         if(par()$mfrow[1] > 2) par(mfrow = c(2,2))
-         if(par()$mfrow[1] > 1) u <- 0 else u  <- 2
+         if (par()$mfrow[1] > 2) par(mfrow = c(2,2))
+         if (par()$mfrow[1] > 1) u <- 0 else u  <- 2
          par(mar= rep(u, 4), mai = rep(0.2, 4))
          
          
@@ -145,7 +148,7 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
          
          #change background color
          rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = 
-                cm.colors(10)[3])
+               adjustcolor("#07889B", alpha.f = 0.2))
          
          #plot lat lon lines in background
          abline(h = seq(-90, 90, 5), col = "white", lwd = 0.9)
@@ -155,8 +158,10 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
          
          #add map
          maps::map("world", xlim = c(min(lon) - buf, max(lon) + buf), add = TRUE,
+                   ylim = c(min(lat) - buf, max(lat) + buf), fill = TRUE, col = "white")
+          maps::map("world", xlim = c(min(lon) - buf, max(lon) + buf), add = TRUE,
                    ylim = c(min(lat) - buf, max(lat) + buf), fill = TRUE, 
-                   col = terrain.colors(10)[5], myborder = 0, interior =  F, lty = 2)
+                   col = adjustcolor("darkolivegreen2", alpha.f = 0.7), myborder = 0, interior =  F, lty = 2)
          mtext("Longitude (DD)", side = 1, line = 2)
          mtext("Latitude (DD)", side = 2, line = 2)
          mtext(i, side =3, line = 1, cex = 1, font = 4)
@@ -169,10 +174,11 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
                    ylim = c(min(lat) - buf, max(lat) + buf), fill = FALSE, add = TRUE)  
          
          # add points
-         points(lon, lat, pch = 21, cex = 1.8, col = "black", bg= heat.colors(10)[2])
+         points(lon, lat, pch = 21, cex = 1.3, bg= "white")
+         points(lon, lat, pch = 21, cex = 1.3, col = "gray3", bg= adjustcolor("#E37222", alpha.f = 0.7), lwd = 0.7)
         
         #add labels 
-         if(labels)
+         if (labels)
         text(lon, lat, labels = X$Recording_ID, cex = 0.7, pos = 4)
          
          # add scale
